Skip to contents

Calculates the estimated density of a location, given its observed capture history and auxiliary information.

Usage

location_density(
  fit,
  call_id,
  animal_id = NULL,
  session = 1,
  mask = get_mask(fit)[[session]],
  warn_toa = F,
  newdata = NULL
)

Arguments

fit

an object generated from the model fitting function fit.acre or the bootstrap process boot.acre.

call_id

an numeric vector indicating which call ID's to calculate density for.

animal_id

an numeric value indicating animal ID. Should only be specified if fit is an animalID model.

session

an integer value indicating the session of detector array and individual(s) to be plotted.

mask

a list or a data frame. Generated by create.mask().

warn_toa

a logical value indicates whether to issue warning in the case of toa data with only a single call.

newdata

data.frame; contains any covariates that will be used for all extended parameters.