Skip to contents

Title

Usage

# S3 method for class 'acreboot'
predict(
  object,
  type = "response",
  newdata = NULL,
  se.fit = TRUE,
  confidence = TRUE,
  level = 0.95,
  realnames = NULL,
  correct_bias = FALSE,
  from_boot = TRUE,
  ...
)

Arguments

object

an object generated by the bootstrap function "boot.acre()".

type

a character vector, the same as "predict.acre()".

newdata

a data frame, the same as "predict.acre()".

se.fit

a logical value indicates whether to show standard error.

confidence

a logical value indicates whether to show confidence interval.

level

a numeric value indicates the confident level, default is 0.95.

realnames

a character vector, the same as "predict.acre()".

correct_bias

a logical value indicates whether to apply the bias correction method to the point estimations and the confidence intervals. The method is described in the functions "coef.acreboot()" and "confint.acreboot()".

from_boot

a logical value indicates whether to extract standard error and confidence interval from the bootstrap results.

...

For S3 compatibility.