Extract standard errors of the estimated parameters from acre models
Source:R/methods.R
stdEr.acre.RdExtract standard errors of the estimated parameters from acre models
Usage
# S3 method for class 'acre'
stdEr(
object,
types = NULL,
pars = NULL,
new.covariates = NULL,
show_fixed_par = TRUE,
...
)