Skip to contents

Summarise acre Model Fits

Usage

# S3 method for class 'acre'
summary(object, derived_print = FALSE, ...)

Arguments

object

an object generated from the model fitting function "fit.acre()" or the bootstrap process "boot.acre()".

derived_print

a logical value indicates whether to show the estimations of "esa".

...

For S3 compatibility.