Bootstrapping a fitted acre model
Arguments
- fit
a model object generated by
fit.acre.- N
a numerical value indicates the number of iterations of the bootstrap process.
- n.cores
a numerical value indicates the number of cores to be used. Currently this function doesn't support parallel computing, so it is fixed to be 1.
- infotypes
a character vector containing the infotypes will be simulated in the additional bootstraps; or a list with each element as a character vector, used for doing multiple additional bootstraps with different settings of infotypes.
- seed
a numerical value indicates the seed for the randomness.