acre
R/methods.R
summary.acre.Rd
Summarise acre Model Fits
# S3 method for class 'acre' summary(object, derived_print = FALSE, ...)
an object generated from the model fitting function "fit.acre()" or the bootstrap process "boot.acre()".
a logical value indicates whether to show the estimations of "esa".
For S3 compatibility.