Extract variance covariance matrix of the estimated parameters from acre models
Source:R/methods.R
vcov.acre.RdExtract variance covariance matrix of the estimated parameters from acre models
Usage
# S3 method for class 'acre'
vcov(
object,
types = NULL,
pars = NULL,
new.covariates = NULL,
show_fixed_par = TRUE,
...
)Arguments
- object
a fitted model from fit.acre().
- types
a character vector, the same as "coef.acre()".
- pars
a character vector, the same as "coef.acre()".
- new.covariates
a data frame, the same as "coef.acre()".
- show_fixed_par
a logical value. To control whether to include the fixed parameters in the covariance matrix. It is TRUE by default.
- ...
For S3 compatibility.